%clear
%% Analytical solution to Fractional Diffusion Equation
L = 3; % spatial domain [0,L]
N = 40; % number of terms in the sum
D = 1; % diffusion coefficient
alpha = [2,1.5,1.2]; % fractional power;
T = 0.1; % final time
f = @(x) dirac(x-L/2); % initial condition

u1 = analytic_sol_FDE(L,N,D,alpha(1),T,f);
u2 = analytic_sol_FDE(L,N,D,alpha(2),T,f);
u3 = analytic_sol_FDE(L,N,D,alpha(3),T,f);
figure;
h(1) = fplot(u1,[0,L],'r','Linewidth',2);
hold on
h(2) = fplot(u2,[0,L],'g','Linewidth',2);
h(3) = fplot(u3,[0,L],'b','Linewidth',2);
title({'Analytic solution of FDE with fractional Laplacian', 'BC: zero Dirichlet, IC: \delta(x-L/2)'})
legend(h,'\alpha = 2','\alpha = 1.5','\alpha = 1.2')

function u = analytic_sol_FDE(L,N,D,alpha,T,f)
syms xi x
u = 0;
for n = 1:N
    bn = 2/L*int(f(xi)*sin(n*pi*xi/L),xi,[0,L]);
    phi = sin(n*pi*x/L);
    lambda = (n*pi/L)^2;
    u = bn*exp(-D*lambda^(alpha/2)*T)*phi + u;
end
end

